# Bootstrap

Sleek, intuitive, and powerful front-end framework for faster and easier web development.

Download Bootstrap

- GitHub project
- Examples
- Extend
- Version 2.3.2

- Follow @twbootstrap
- Tweet

# Introducing Bootstrap.

Need reasons to love Bootstrap? Look no further.

## By nerds, for nerds.

Built at Twitter by @mdo and @fat, Bootstrap utilizes LESS CSS, is compiled via Node, and is managed through GitHub to help nerds do awesome stuff on the web.

## Made for everyone.

Bootstrap was made to not only look and behave great in the latest desktop browsers (as well as IE7!), but in tablet and smartphone browsers via responsive CSS as well.

## Packed with features.

A 12-column responsive grid, dozens of components, JavaScript plugins, typography, form controls, and even a web-based Customizer to make Bootstrap your own.

# Built with Bootstrap.

For even more sites built with Bootstrap, visit the unofficial Tumblr or browse the examples.